@@ -103,6 +103,11 @@ def app_for_adapter(adapter, gzip=False, dev=False):
 
         Default: False
 
+    dev: Boolean, optional
+        If True, listen to anyone for CORS.
+
+        Default: False
+
     Returns
     -------
 
